@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.28 2003/06/24 16:06:49 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.30 2003/08/26 21:29:17 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -24,7 +24,7 @@
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
 #define HAVE_BACON_VIDEO_WIDGET_H
 
-#include <gtk/gtkvbox.h>
+#include <gtk/gtkbox.h>
 
 G_BEGIN_DECLS
 
@@ -74,6 +74,7 @@ typedef enum {
 	BVW_AUDIO_SOUND_4CHANNEL,
 	BVW_AUDIO_SOUND_5CHANNEL,
 	BVW_AUDIO_SOUND_51CHANNEL,
+	BVW_AUDIO_SOUND_AC3PASSTHRU,
 } BaconVideoWidgetAudioOutType;
 
 #define BACON_VIDEO_WIDGET(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), bacon_video_widget_get_type (), BaconVideoWidget))
@@ -84,12 +85,12 @@ typedef enum {
 typedef struct BaconVideoWidgetPrivate BaconVideoWidgetPrivate;
 
 typedef struct {
-	GtkVBox parent;
+	GtkBox parent;
 	BaconVideoWidgetPrivate *priv;
 } BaconVideoWidget;
 
 typedef struct {
-	GtkVBoxClass parent_class;
+	GtkBoxClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message,
                        gboolean playback_stopped);
